@@ -1,3 +1,4 @@
+from flex_ansible.command.wrapper.ansible import AnsibleWrapper
 from lcli.command.builders import (
     CommandBuilderFactory,
     LcliBuilder,
@@ -9,3 +10,5 @@ from lcli.command.builders import (
 CommandBuilderFactory.register_builder(LcliBuilder)
 CommandBuilderFactory.register_builder(SimpleBuilder)
 CommandBuilderFactory.register_builder(WrappersBuilder)
+CommandBuilderFactory.register_builder(WrappersBuilder)
+CommandBuilderFactory.register_builder(AnsibleWrapper)
