@@ -518,7 +518,7 @@ class CommandCollection(Config):
         self,
         commands_list: "CommandCollection",
         ignored_commands: list,
-        available_groups: list = [],
+        available_groups=None,
     ) -> dict:
         """
         Returns the directly/first accessible commands for a command list
@@ -530,16 +530,18 @@ class CommandCollection(Config):
         :param available_groups:
         :return: dict containing the first level commands described above
         """
+        if available_groups is None:
+            available_groups = []
         result = {}
         if type(commands_list) == CommandCollection:
             for key in commands_list:
                 if key in ignored_commands:
                     continue
                 command = commands_list.get_command(key)
-                if command.is_group():
+                if command.is_group() and command.name == "groups":
                     if command.name in available_groups:
                         sub_class_commands = self.get_first_level_commands(
-                            command.commands, ignored_commands
+                            command.commands, ignored_commands, available_groups
                         )
                         for sub_command_key in sub_class_commands:
                             result[sub_command_key] = sub_class_commands[
